<?php

namespace domain\PointSale\PointSale;

use domain\PointSale\UserPointSale\UserPointSale;
use domain\PointSale\UserPointSale\UserPointSaleBuilder;
use domain\PointSale\UserPointSale\UserPointSaleRepository;
use domain\Producer\Producer\Producer;
use domain\User\User\User;
use domain\User\User\UserRepository;
use domain\_\AbstractBuilder;

class PointSaleBuilder extends AbstractBuilder
{
    protected UserPointSaleBuilder $userPointSaleBuilder;
    protected UserRepository $userRepository;
    protected UserPointSaleRepository $userPointSaleRepository;

    public function loadDependencies(): void
    {
        $this->userPointSaleBuilder = $this->loadService(UserPointSaleBuilder::class);
        $this->userRepository = $this->loadService(UserRepository::class);
        $this->userPointSaleRepository = $this->loadService(UserPointSaleRepository::class);
    }

    public function instanciatePointSale(): PointSale
    {
        $pointSale = new PointSale();

        $pointSale->button_generate_delivery_note_point_sale = true;
        $pointSale->button_generate_delivery_note_each_user = true;

        return $pointSale;
    }

    public function createPointSale(): PointSale
    {
        $pointSale = $this->instanciatePointSale();
        $this->saveCreate($pointSale);

        return $pointSale;
    }

    // resetPointProductions
    public function resetPointSalePointProductions(Producer $producer): void
    {
        PointSale::updateAll(
            ['point_production' => 0],
            ['id_producer' => $producer->id]
        );
    }

    /**
     * Traite la mise à jour de l'attribut 'point_production'.
     */
    // processPointProduction
    // updatePointProduction
    public function updatePointSalePointProduction(PointSale $pointSale): void
    {
        if ($pointSale->point_production) {
            $this->resetPointSalePointProductions($pointSale->producer);
            $pointSale->point_production = 1;
            $this->saveUpdate($pointSale);
        }
    }

    /**
     * Traite les accès restreints d'un point de vente.
     */
    public function processRestrictedAccess(PointSale $pointSale): void
    {
        $this->userPointSaleBuilder->deleteUserPointSalesByPointSale($pointSale);

        if (is_array($pointSale->users) && count($pointSale->users)) {
            foreach ($pointSale->users as $key => $val) {
                $user = $this->userRepository->findOneUserById($val);
                if ($user) {
                    $this->userPointSaleBuilder->createUserPointSale($user, $pointSale, $pointSale->users_comment[$val]);
                }
            }
        }
    }

    /**
     * Lie un utilisateur au point de vente.
     */
    // linkUser
    public function addUser(User $user, PointSale $pointSale): UserPointSale
    {
        return $this->userPointSaleBuilder->createUserPointSaleIfNotExist($user, $pointSale);
    }

    public function initPaymentMethodsByCreditFunctioning(PointSale $pointSale): bool
    {
        if($pointSale->payment_method_credit) {
            if($pointSale->credit_functioning == Producer::CREDIT_FUNCTIONING_OPTIONAL && !$pointSale->payment_method_onsite) {
                $pointSale->payment_method_onsite = true;
                $this->update($pointSale);
                return true;
            }
            if($pointSale->credit_functioning == Producer::CREDIT_FUNCTIONING_MANDATORY && $pointSale->payment_method_onsite) {
                $pointSale->payment_method_onsite = false;
                $this->update($pointSale);
                return true;
            }
            if($pointSale->credit_functioning == Producer::CREDIT_FUNCTIONING_MANDATORY && $pointSale->payment_method_online) {
                $pointSale->payment_method_online = false;
                $this->update($pointSale);
                return true;
            }
        }

        return false;
    }
}