<?php

namespace domain\Producer\Producer;

use domain\_\AbstractGenerator;
use domain\PointSale\PointSale\PointSaleRepository;
use domain\Product\Product\ProductRepository;
use yii\helpers\Html;

class ProducerSeoGenerator extends AbstractGenerator
{
    protected ProductRepository $productRepository;
    protected PointSaleRepository $pointSaleRepository;

    public function loadDependencies(): void
    {
        $this->productRepository = $this->loadService(ProductRepository::class);
        $this->pointSaleRepository = $this->loadService(PointSaleRepository::class);
    }

    public function generateMetaDescriptionHome()
    {
        $producer = $this->getProducerContext();

        if($producer->description) {
            $metaDescription = substr(strip_tags($producer->description), 0, 200);
        }
        else {
            $metaDescription = "Bienvenue sur la boutique du producteur ".Html::encode($producer->name);
        }

        return $metaDescription;
    }

    public function generateMetaDescriptionProducts()
    {
        $metaDescription = '';
        $productsArray = $this->productRepository->findProducts();

        foreach($productsArray as $product) {
            $metaDescription .= Html::encode($product->name).', ';
        }

        if(strlen($metaDescription)) {
            $metaDescription = substr($metaDescription, 0, strlen($metaDescription) - 2);
        }

        return $metaDescription;
    }

    public function generateMetaDescriptionPointsSale()
    {
        $metaDescription = '';
        $pointsSaleArray = $this->pointSaleRepository->findPointSales();

        foreach($pointsSaleArray as $pointSale) {
            $metaDescription .= Html::encode($pointSale->name).', ';
        }

        if(strlen($metaDescription)) {
            $metaDescription = substr($metaDescription, 0, strlen($metaDescription) - 2);
        }

        return $metaDescription;
    }

    public function generateMetaDescriptionOrder()
    {
        $producer = $this->getProducerContext();
        return "Passez commande chez ".Html::encode($producer->name)." à la date et au lieu de votre choix.";
    }

    public function generateMetaDescriptionContact()
    {
        $producer = $this->getProducerContext();
        return 'Contactez ce producteur en utilisant le formulaire de contact. '
            .Html::encode($producer->name.', '.$producer->address.' '.$producer->postcode.' '.$producer->city);
    }
}