<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace backend\controllers;

use common\helpers\Ajax;
use yii\filters\AccessControl;
use yii\helpers\Html;
use yii\web\NotFoundHttpException;

/**
 * UserController implements the CRUD actions for User model.
 */
class FeatureAdminController extends BackendController
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                        'matchCallback' => function ($rule, $action) {
                            return $this->getUserModule()
                                ->getAuthorizationChecker()
                                ->isGrantedAsAdministrator($this->getUserCurrent());
                        }
                    ]
                ],
            ],
        ];
    }

    public function actionIndex()
    {
        $featureModule = $this->getFeatureModule();
        $dataProviderFeatures = $featureModule->getRepository()->queryDefaultAll()->getDataProvider(100);

        return $this->render('index', [
            'producerCurrent' => $this->getProducerCurrent(),
            'dataProviderFeatures' => $dataProviderFeatures
        ]);
    }

    public function actionAjaxToggleStatus($id, $status)
    {
        $featureManager = $this->getFeatureModule()->getManager();
        $feature = $this->findModel($id);

        if($status) {
            $featureManager->enableFeature($feature);
            $messageResponse = 'La fonctionnalité "'.Html::encode($feature->name).'" a bien été activée';
        }
        else {
            $featureManager->disableFeature($feature);
            $messageResponse = 'La fonctionnalité "'.Html::encode($feature->name).'" a bien été désactivée';
        }

        return Ajax::responseSuccess($messageResponse);
    }

    public function actionToggleStatusFeatureProducer(int $id, int $status = null)
    {
        $featureManager = $this->getFeatureModule()->getManager();
        $feature = $this->findModel($id);

        if(is_null($status)) {
            $featureManager->defaultFeatureForProducer($feature);
        }
        elseif($status == 0) {
            $featureManager->disableFeatureForProducer($feature);
        }
        elseif($status == 1) {
            $featureManager->enableFeatureForProducer($feature);
        }

        return $this->redirectReferer();
    }

    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(\Yii::$app->request->post()) && $model->save()) {
            $this->setFlash('success', 'Fonctionnalité modifiée.');
            return $this->redirect(['index']);
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
    }

    public function actionPosition()
    {
        $array = \Yii::$app->request->post('array');
        $positionArray = json_decode(stripslashes($array));

        foreach ($positionArray as $id => $position) {
            $feature = $this->findModel($id);
            $feature->position = $position;
            $feature->save();
        }
    }

    protected function findModel($id)
    {
        $featureModule = $this->getFeatureModule();
        if (($feature = $featureModule->getRepository()->findOneFeatureById($id)) !== null) {
            return $feature;
        } else {
            throw new NotFoundHttpException('La fonctionnalité demandée est introuvable.');
        }
    }
}
