<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace backend\controllers;

use domain\Producer\ProducerPriceRange\ProducerPriceRange;
use yii\data\ActiveDataProvider;
use yii\filters\AccessControl;
use yii\web\NotFoundHttpException;

/**
 * ProducerPriceRangeAdminController implements the CRUD actions for ProducerPriceRange model.
 */
class ProducerPriceRangeAdminController extends BackendController
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                        'matchCallback' => function ($rule, $action) {
                            return $this->getUserModule()
                                ->getAuthorizationChecker()
                                ->isGrantedAsAdministrator($this->getUserCurrent());
                        }
                    ]
                ],
            ],
        ];
    }

    /**
     * Liste les tranches de prix.
     */
    public function actionIndex()
    {
        $dataProvider = new ActiveDataProvider([
            'query' => ProducerPriceRange::find()->orderBy('range_begin ASC')
        ]);

        return $this->render('index', [
            'dataProviderProducerPriceRange' => $dataProvider,
        ]);
    }

    /**
     * Crée une tranche de prix.
     */
    public function actionCreate()
    {
        $producerPriceRangeModule = $this->getProducerPriceRangeModule();
        $producerPriceRange = $producerPriceRangeModule->instanciateProducerPriceRange();

        if ($producerPriceRange->load(\Yii::$app->request->post())
            && $producerPriceRangeModule->saveCreate($producerPriceRange)) {

            $this->setFlash('success', 'Tranche de prix créée.');

            return $this->redirect(['index']);
        } else {
            return $this->render('create', [
                'model' => $producerPriceRange,
            ]);
        }
    }

    /**
     * Édition d'une tranche de prix.
     */
    public function actionUpdate(int $id)
    {
        $producerPriceRangeModule = $this->getProducerPriceRangeModule();
        $producerPriceRange = $this->findModel($id);

        if ($producerPriceRange->load(\Yii::$app->request->post()) && $producerPriceRangeModule->saveUpdate($producerPriceRange)) {
            $this->setFlash('success', 'Tranche de prix éditée.');
            return $this->redirect(['index']);
        } else {
            return $this->render('update', [
                'model' => $producerPriceRange,
            ]);
        }
    }

    /**
     * Supprime une tranche de prix.
     */
    public function actionDelete(int $id)
    {
        $producerPriceRangeModule = $this->getProducerPriceRangeModule();

        $producerPriceRange = $this->findModel($id);
        $producerPriceRangeModule->delete($producerPriceRange);
        $this->setFlash('success', 'Tranche de prix supprimée.');

        return $this->redirect(['producer-price-range-admin/index']);
    }

    protected function findModel($id)
    {
        $producerPriceRangeModule = $this->getProducerPriceRangeModule();
        if (($producerPriceRange = $producerPriceRangeModule->findOneProducerPriceRangeById($id)) !== null) {
            return $producerPriceRange;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
