<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use domain\Document\DeliveryNote\DeliveryNote;
use domain\Order\Order\Order;
use domain\PointSale\PointSale\PointSale;
use yii\grid\GridView;
use yii\helpers\ArrayHelper;
use yii\helpers\Html;

$deliveryNoteModule = $this->getDeliveryNoteModule();

$this->setTitle('Bons de livraison');
$this->addBreadcrumb($this->getTitle());
$this->addButton(['label' => 'Nouveau bon de livraison <span class="glyphicon glyphicon-plus"></span>', 'url' => ['distribution/index', 'message_generate_bl' => 1], 'class' => 'btn btn-primary']);

?>

<div class="delivery-note-index">
    <?php if (DeliveryNote::searchCount()): ?>
        <?= GridView::widget([
            'filterModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'columns' => [
                [
                    'attribute' => 'status',
                    'label' => 'Statut',
                    'filter' => [
                        'draft' => 'Brouillon',
                        'valid' => 'Valide',
                    ],
                    'format' => 'raw',
                    'value' => function ($model) use ($deliveryNoteModule) {
                        return $deliveryNoteModule->getHtmlLabel($model);
                    }
                ],
                [
                    'attribute' => 'reference',
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($model) {
                        return (strlen($model->reference) > 0) ? $model->reference : '';
                    }
                ],
                'name',
                [
                    'attribute' => 'date_distribution',
                    'header' => 'Jour de distribution',
                    'filter' => \yii\jui\DatePicker::widget([
                        'language' => 'fr',
                        'dateFormat' => 'dd/MM/yyyy',
                        'model' => $searchModel,
                        'attribute' => 'date_distribution',
                        'options' => ['class' => 'form-control']
                    ]),
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($model) use ($deliveryNoteModule) {
                        $distribution = $deliveryNoteModule->getDistribution($model);
                        return $distribution ? date('d/m/Y', strtotime($distribution->date)) : '';
                    }
                ],
                [
                    'attribute' => 'id_point_sale',
                    'header' => 'Point de vente',
                    'filter' => ArrayHelper::map(PointSale::searchAll([], ['as_array' => true]), 'id', 'name'),
                    'format' => 'html',
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($model) use ($deliveryNoteModule) {
                        $pointSale = $deliveryNoteModule->getPointSale($model);
                        return $pointSale ? Html::encode($pointSale->name) : '';
                    }
                ],
                [
                    'attribute' => 'amount',
                    'header' => 'Montant',
                    'value' => function ($deliveryNote) use ($deliveryNoteModule) {
                        return $deliveryNoteModule->getAmountWithTax($deliveryNote, Order::INVOICE_AMOUNT_TOTAL, true);
                    }
                ],
                [
                    'attribute' => 'is_sent',
                    'header' => 'Envoyé',
                    'format' => 'raw',
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($model) {
                        if ($model->is_sent) {
                            return '<span class="label label-success">Oui</span>';
                        } else {
                            return '<span class="label label-default">Non</span>';
                        }
                    }
                ],
                [
                    'class' => 'yii\grid\ActionColumn',
                    'template' => '{validate} {update} {delete} {send} {download}',
                    'headerOptions' => ['class' => 'column-actions'],
                    'contentOptions' => ['class' => 'column-actions'],
                    'buttons' => [
                        'send' => function ($url, $deliveryNote) use ($deliveryNoteModule) {
                            return ((isset($deliveryNote->user) && strlen($deliveryNote->user->email) > 0) ? Html::a('<span class="glyphicon glyphicon-send"></span>', $url, [
                                'title' => 'Envoyer', 'class' => 'btn btn-default'
                            ]) : '');
                        },
                        'download' => function ($url, $deliveryNote) {
                            return Html::a('<span class="glyphicon glyphicon-download-alt"></span>', $url, [
                                'title' => 'Télécharger', 'class' => 'btn btn-default'
                            ]);
                        },
                        'validate' => function ($url, $deliveryNote) use ($deliveryNoteModule) {
                            return ($deliveryNoteModule->isStatusDraft($deliveryNote) ? Html::a('<span class="glyphicon glyphicon-ok"></span>', $url, [
                                'title' => 'Valider', 'class' => 'btn btn-default'
                            ]) : '');
                        },
                        'update' => function ($url, $deliveryNote) {
                            return Html::a('<span class="glyphicon glyphicon-pencil"></span>', $url, [
                                'title' => 'Modifier', 'class' => 'btn btn-default'
                            ]);
                        },
                        'delete' => function ($url, $deliveryNote) use ($deliveryNoteModule) {
                            return ($deliveryNoteModule->isStatusDraft($deliveryNote) ? Html::a('<span class="glyphicon glyphicon-trash"></span>', $url, [
                                'title' => 'Supprimer', 'class' => 'btn btn-default'
                            ]) : '');
                        }
                    ],
                ],
            ],
        ]); ?>
    <?php else: ?>
        <div class="alert alert-info">Aucun bon de livraison enregistré</div>
    <?php endif; ?>
</div>
