<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\helpers\Price;
use lo\widgets\Toggle;
use yii\helpers\Html;
use yii\grid\GridView;

$this->setTitle('Fonctionnalités');
$this->addBreadcrumb($this->getTitle());

?>

<div class="feature-admin-index">
    <?= GridView::widget([
        'dataProvider' => $dataProviderFeatures,
        'columns' => [
            [
                'attribute' => 'position',
                'headerOptions' => ['class' => 'position'],
                'format' => 'raw',
                'filter' => '',
                'value' => function ($model) {
                    return '<a class="btn-position btn btn-default" href="javascript:void(0);"><span class="glyphicon glyphicon-resize-vertical"></span></a>';
                }
            ],
            'name',
            [
                'attribute' => 'status',
                'headerOptions' => ['class' => 'status column-hide-on-mobile'],
                'filterOptions' => ['class' => 'column-hide-on-mobile'],
                'contentOptions' => ['class' => 'center column-hide-on-mobile'],
                'format' => 'raw',
                'filter' => [0 => 'Désactivée', 1 => 'Activée'],
                'value' => function ($model) {
                    return Toggle::widget(
                        [
                            'name' => 'active',
                            'checked' => $model->status,
                            'options' => [
                                'data-id' => $model->id,
                                'data-on' => 'Activée',
                                'data-off' => 'Désactivée',
                            ],
                        ]
                    );
                }
            ],
            [
                'attribute' => 'producers',
                'label' => 'Producteurs',
                'headerOptions' => ['class' => 'column-hide-on-mobile'],
                'filterOptions' => ['class' => 'column-hide-on-mobile'],
                'contentOptions' => ['class' => 'column-hide-on-mobile'],
                'format' => 'raw',
                'value' => function ($model) {
                    $html = '';
                    foreach($model->featureProducers as $featureProducer) {
                        if(!is_null($featureProducer->status)) {
                            $html .= feature_status_producer($featureProducer->producer->name, $featureProducer->status);
                        }
                    }

                    return $html;
                }
            ],
            [
                'attribute' => 'only_for_selected_producers',
                'label' => "Producteurs sélectionnés",
                'headerOptions' => ['class' => 'only-for-selected-producers column-hide-on-mobile'],
                'filterOptions' => ['class' => 'column-hide-on-mobile'],
                'contentOptions' => ['class' => 'only-for-selected-producers column-hide-on-mobile'],
                'format' => 'raw',
                'value' => function ($model) {
                    return '<span class="label label-'.($model->only_for_selected_producers ? 'success' : 'default').'">'
                        .($model->only_for_selected_producers ? 'Oui' : 'Non') .'</span>';
                }
            ],
            [
                'attribute' => 'is_paid_feature',
                'headerOptions' => ['class' => 'column-hide-on-mobile'],
                'filterOptions' => ['class' => 'column-hide-on-mobile'],
                'contentOptions' => ['class' => 'column-hide-on-mobile'],
                'format' => 'raw',
                'value' => function ($model) {
                    return '<span class="label label-'.($model->is_paid_feature ? 'success' : 'default').'">'
                        .($model->is_paid_feature ? 'Oui' : 'Non') .'</span>';
                }
            ],
            [
                'attribute' => 'price',
                'headerOptions' => ['class' => 'column-hide-on-mobile'],
                'filterOptions' => ['class' => 'column-hide-on-mobile'],
                'contentOptions' => ['class' => 'column-hide-on-mobile'],
                'format' => 'raw',
                'value' => function ($model) {
                    if($model->is_paid_feature && $model->price) {
                        return Price::format($model->price, 0);
                    }

                    return '';
                }
            ],
            [
                'class' => 'yii\grid\ActionColumn',
                'template' => '{toggle_status_feature_producer} {update}',
                'headerOptions' => ['class' => 'column-actions'],
                'contentOptions' => ['class' => 'column-actions'],
                'buttons' => [
                    'toggle_status_feature_producer' => function ($url, $model) use ($producerCurrent) {
                        return '<div class="dropdown">
                          <button class="btn btn-default dropdown-toggle" type="button" id="dropdownMenu1" data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">
                            '.Html::encode($producerCurrent->name).'
                            <span class="caret"></span>
                          </button>
                          <ul class="dropdown-menu" aria-labelledby="dropdownMenu1">
                            <li><a href="'.Yii::$app->urlManager->createUrl(['feature-admin/toggle-status-feature-producer', 'id' => $model->id]).'">Par défaut</a></li>
                            <li><a href="'.Yii::$app->urlManager->createUrl(['feature-admin/toggle-status-feature-producer', 'id' => $model->id, 'status' => 1]).'">Activer</a></li>
                            <li><a href="'.Yii::$app->urlManager->createUrl(['feature-admin/toggle-status-feature-producer', 'id' => $model->id, 'status' => 0]).'">Désactiver</a></li>
                          </ul>
                        </div>';
                    },
                    'update' => function ($url, $model) {
                        return Html::a('<span class="glyphicon glyphicon-pencil"></span>', $url, [
                            'title' => 'Modifier', 'class' => 'btn btn-default'
                        ]);
                    },
                ],
            ],
        ]
    ]);
    ?>
</div>

<?php

function feature_status_producer($producerName, $status): string {
    return '<span class="label label-'.($status ? 'success' : 'danger').'">'.Html::encode($producerName).'</span> ';
}

?>