<?php

/** 
Copyright Souke (2018)

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs 
à distribuer leur production en circuits courts. 

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant 
donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
*/

use common\helpers\Price;
use domain\Producer\Producer\Producer;
use domain\User\User\User;
use yii\grid\GridView;
use yii\helpers\Html;

$producerModule = $this->getProducerModule();

$this->setTitle('Producteurs') ;
$this->addBreadcrumb($this->getTitle()) ;
$this->addButton(['label' => 'Nouveau producteur <span class="glyphicon glyphicon-plus"></span>', 'url' => 'producer-admin/create', 'class' => 'btn btn-primary']) ;

?>
<div class="producer-admin-index">
    <?= GridView::widget([
        'dataProvider' => $dataProviderProducer,
        'columns' => [
            [
                'attribute' => 'active',
                'format' => 'raw',
                'value' => function($model) {
                    $html = '' ;
                    if($model->active) {
                        $html .= '<span class="label label-success">En ligne</span>' ;
                    }
                    else {
                        $html .= '<span class="label label-danger">Hors-ligne</span>' ;
                    }

                    if(strlen($model->code)) {
                        $html .= ' <span class="glyphicon glyphicon-lock" data-toggle="tooltip" data-placement="bottom" title="'.Html::encode($model->code).'"></span>' ;
                    }

                    if($model->is_new) {
                        $html .= ' <span class="label label-info">Nouveau</span>' ;
                    }

                    if(!$model->agree_contact_about_software_development) {
                        $html .= ' <span class="label label-danger">Développement</span>';
                    }

                    return $html ;
                }
            ],
            [
                'attribute' => 'name',
                'format' => 'raw',
                'value' => function($model) {
                    $html = Html::encode($model->name);
                    return $html;
                }
            ],
            [
                'attribute' => 'Contact',
                'format' => 'raw',
                'value' => function($model) {
                    if(!isset($model->user) || (isset($model->user) && count($model->user) == 0))
                    {
                        return 'Aucun contact' ;
                    }
                    else {
                        foreach($model->user as $u)
                        {
                            if($u->status ==  User::STATUS_PRODUCER)
                            {
                                return Html::encode($u->lastname.' '.$u->name)
                                    .'<br />'.Html::encode($u->email)
                                    .'<br />'.Html::encode($u->phone) ;
                            }
                        }
                    }
                }
            ],
            [
                'label' => 'Facturation',
                'format' => 'raw',
                'value' => function($producer) use ($producerModule) {
                    $str = '';
                    $str .= '<ul style="margin: 0px;padding-left: 15px;">';

                    $isBillingFrequencyMonthly = $producerModule->isBillingFrequencyMonthly($producer);
                    $summaryMonthly = $producerModule->getSummaryAmountsToBeBilled($producer, 'Mois dernier', 1);
                    $isBillingFrequencyQuaterly = $producerModule->isBillingFrequencyQuarterly($producer);
                    $summaryQuaterly = $producerModule->getSummaryAmountsToBeBilled($producer, '3 derniers mois', 3);
                    $isBillingFrequencyBiannual = $producerModule->isBillingFrequencyBiannual($producer);
                    $summaryBiannual = $producerModule->getSummaryAmountsToBeBilled($producer, '6 derniers mois', 6);

                    if(($isBillingFrequencyMonthly && $summaryMonthly)
                        || ($isBillingFrequencyQuaterly && $summaryQuaterly)
                        || ($isBillingFrequencyBiannual && $summaryBiannual)) {

                        $str .= '<li>';
                        if ($isBillingFrequencyMonthly && $summaryMonthly) {
                            $str .= $summaryMonthly;
                        } elseif ($isBillingFrequencyQuaterly && $summaryQuaterly) {
                            $str .= $summaryQuaterly;
                        } elseif ($isBillingFrequencyBiannual && $summaryBiannual) {
                            $str .= $summaryBiannual;
                        }

                        if ($producer->option_billing_reduction && strlen($str)) {
                            $str .= '<br /><u>Avec réduction</u> : ';
                            if ($producer->option_billing_reduction_percentage) {
                                $str .= ' ' . $producer->option_billing_reduction_percentage . '&nbsp;%';
                            }
                        }
                        $str .= '</li>';

                        if(!$isBillingFrequencyMonthly) {
                            $str .= '<li>Facturation '.strtolower(Producer::$billingFrequencyArray[$producer->option_billing_frequency]).'</li>';
                        }
                    }

                    if($producer->option_billing_permanent_transfer) {
                        $str .= '<li>Virement permanent : <strong>'.Price::format($producer->option_billing_permanent_transfer_amount).'</strong></li>';
                    }

                    $str .= '</ul>';

                    return $str;
                }
            ],
            [
                'attribute' => 'admin_comment',
                'label' => 'Commentaire',
                'format' => 'raw',
                'value' => function($producer) {
                    $html = '';

                    if($producer->admin_comment) {
                        $html .= $producer->admin_comment;
                    }

                    if($producer->active && (!$producer->latitude || !$producer->longitude)) {
                        $html .= '<div class="alert-latitude-longitude"><span class="glyphicon glyphicon-map-marker"></span> Latitude/longitude à saisir</div>';
                    }

                    return $html;
                }
            ],
            [
                'class' => 'yii\grid\ActionColumn',
                'template' => '{update} {switch} {create-ticket} {billing} {dolibarr} {alwaysdata}',
                'headerOptions' => ['class' => 'column-actions'],
                'contentOptions' => ['class' => 'column-actions'],
                'buttons' => [
                    'update' => function ($url, $model) {
                        return Html::a(
                            '<span class="glyphicon glyphicon-pencil"></span>',
                            $url,
                            [
                                'title' => 'Modifier',
                                'class' => 'btn btn-default'
                            ]
                        );
                    },
                    'switch' => function ($url, $model) {
                        return Html::a(
                            '<span class="glyphicon glyphicon-hand-up"></span>',
                            Yii::$app->urlManager->createUrl(['site/switch-producer', 'id' => $model->id]),
                            [
                                'title' => 'Aller sur le compte de ce producteur',
                                'class' => 'btn btn-default'
                            ]
                        );
                    },
                    'create-ticket' => function ($url, $model) {
                        return Html::a(
                            '<span class="glyphicon glyphicon-comment"></span>',
                            Yii::$app->urlManager->createUrl(['site/switch-producer', 'id' => $model->id, 'createTicket' => true]),
                            [
                                'title' => 'Créer un ticket',
                                'class' => 'btn btn-default'
                            ]
                        );
                    },
                    'dolibarr' => function ($url, $model) {
                        return Html::a(
                            '<i class="bi bi-clipboard-check"></i>',
                            $url,
                            [
                                'title' => 'Générer la facture sur Dolibarr',
                                'class' => 'btn btn-default btn-dolibarr'
                            ]
                        );
                    },
                    'billing' => function ($url, $model) {
                        return Html::a(
                            '<span class="glyphicon glyphicon-euro"></span>',
                            $url,
                            [
                                'title' => 'Facturation',
                                'class' => 'btn btn-default'
                            ]
                        );
                    },
                    'alwaysdata' => function ($url, $model) {
                        return Html::a(
                            '<span class="glyphicon glyphicon-road"></span>',
                            $url,
                            [
                                'title' => 'Redirections Alwaysdata (email et url courte)',
                                'class' => 'btn btn-default btn-alwaysdata'
                            ]
                        );
                    },
                ],
            ],
        ],
    ]); ?>

</div>
