<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use domain\Setting\SettingModule;
use lo\widgets\Toggle;
use yii\bootstrap\ActiveForm;
use yii\helpers\Html;

$settingModule = SettingModule::getInstance();
$adminSettingDefinition = $settingModule->getAdminSettingDefinition();

$this->setTitle('Paramètres');
$this->addBreadcrumb($this->getTitle());

?>

<script>
    var appInitValues = {
        sectionsArray: <?php echo json_encode($adminSettingDefinition->getSectionsArray()); ?>,
    };
</script>

<div class="setting-admin-index setting-form" id="app-setting-admin">

    <div id="nav-params">
        <a v-for="section in sectionsArray" :class="'btn '+((currentSection == section.name) ? 'btn-primary' : 'btn-default')"
           @click="changeSection(section)" :href="'#'+section.name">
            {{ section.nameDisplay }}
        </a>
    </div>

    <?php $form = ActiveForm::begin(); ?>
    <?php foreach($adminSettingDefinition->getSettingDetails() as $sectionName => $sectionsArray): ?>
        <div v-show="currentSection == '<?= $sectionName ?>'" class="panel panel-default">
            <div class="panel-body">
        <?php foreach($sectionsArray as $subSectionName => $subSectionsArray): ?>
            <h4><?php echo $adminSettingDefinition->getSectionLabelBySectionName($subSectionName); ?></h4>
            <?php foreach($subSectionsArray as $settingDetail): ?>
                <?php echo field($form, $model, $settingDetail); ?>
            <?php endforeach; ?>
        <?php endforeach; ?>
            </div>
        </div>
    <?php endforeach; ?>
    <div class="form-group">
        <?= Html::submitButton('Sauvegarder', ['class' => 'btn btn-primary']) ?>
    </div>
    <?php ActiveForm::end(); ?>
</div>

<?php

function field($form, $model, $settingDetail) {
    $field = $form->field($model, $settingDetail->getName());
    if($settingDetail->getFormType() == 'checkbox') {
        $field = $field->checkbox();
    }
    elseif($settingDetail->getFormType() == 'toggle') {
        $field = $form->field($model, $settingDetail->getName(), ['options' => ['class' => 'form-group form-toggle']])->widget(Toggle::class, ['options' => ['data-on' => 'Oui', 'data-off' => 'Non', 'data-offstyle' => 'danger']]);
    }
    elseif($settingDetail->getFormType() == 'select') {
        $field = $field->dropDownList($settingDetail->getOptions());
    }
    elseif($settingDetail->getFormType() == 'textarea') {
        $field = $field->textarea(['rows' => 4]);
    }
    elseif($settingDetail->getFormType() == 'input') {
        $field = $field->textInput();
    }
    else {
        return '<div class="form-group"><span class="glyphicon glyphicon-alert"></span> Type de champ non défini pour le paramètre "'.$settingDetail->getName().'"</div>';
    }

    if($settingDetail->getHelpMessage()) {
        $field->hint($settingDetail->getHelpMessage());
    }

    return $field;
}

?>