<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\helpers\GlobalParam;
use common\helpers\Price;
use domain\Order\Order\Order;
use domain\Producer\Producer\ProducerModule;
use domain\User\User\User;
use domain\User\User\UserModule;
use domain\User\UserProducer\UserProducer;
use domain\User\UserProducer\UserProducerModule;
use yii\grid\GridView;
use yii\helpers\Html;
use domain\User\UserGroup\UserGroupModule;

$userModule = UserModule::getInstance();
$producerModule = ProducerModule::getInstance();
$userCurrent = GlobalParam::getCurrentUser();
$userGroupModule = UserGroupModule::getInstance();
$userProducerModule = UserProducerModule::getInstance();

$this->setTitle('Utilisateurs');
$this->addBreadcrumb($this->getTitle());

?>

<?= GridView::widget([
    'dataProvider' => $dataProvider,
    'filterModel' => $searchModel,
    'summary' =>
        'Affichage de <b>{begin, number}-{end, number}</b> sur <b>{totalCount, number}</b> {totalCount, plural, one{élément} other{éléments}}.',
    'columns' => [
        [
            'attribute' => 'username',
            'label' => 'Nom',
            'value' => function ($user) use ($userModule) {
                return  $userModule->getUsername($user);
            }
        ],
        [
            'attribute' => 'type',
            'label' => 'Type',
            'headerOptions' => ['class' => 'column-hide-on-mobile'],
            'filterOptions' => ['class' => 'column-hide-on-mobile'],
            'contentOptions' => ['class' => 'column-hide-on-mobile'],
            'filter' => $userModule->getTypeChoicesArray(),
            'value' => function ($user) use ($userModule) {
                return $userModule->getTypeLabel($user['type']);
            }
        ],
        [
            'attribute' => 'contacts',
            'header' => 'Contacts',
            'format' => 'raw',
            'headerOptions' => ['class' => 'column-hide-on-mobile'],
            'filterOptions' => ['class' => 'column-hide-on-mobile'],
            'contentOptions' => ['class' => 'column-hide-on-mobile'],
            'value' => function ($user) {
                $html = '';
                if (strlen($user['phone'])) {
                    $html .= $user['phone'];
                }
                if (strlen($user['phone']) && strlen($user['email'])) {
                    $html .= '<br />';
                }
                if (strlen($user['email'])) {
                    $html .= $user['email'];
                }
                return $html;
            }
        ],
        [
            'attribute' => 'producers',
            'label' => 'Producteurs',
            'format' => 'raw',
            'contentOptions' => ['class' => 'column-hide-on-mobile align-center'],
            'value' => function ($user) use ($userProducerModule) {
                $html = '';
                $userProducersArray = $userProducerModule->getRepository()->findUserProducersByUser($user);

                foreach($userProducersArray as $userProducer) {
                    $html .= '<a href="'.Yii::$app->urlManager->createUrl(['user-admin/redirect-view', 'idUserProducer' => $userProducer->id]).'" class="btn btn-default"><span class="glyphicon glyphicon-eye-open"></span> '.$userProducer->producer->name.'</a> ';
                }

                return $html;
            }
        ],
        [
            'class' => 'yii\grid\ActionColumn',
            'template' => '{switch} ',
            'headerOptions' => ['class' => 'column-actions'],
            'contentOptions' => ['class' => 'column-actions'],
            'buttons' => [
                'view' => function ($url, $user) {
                    return Html::a('<span class="glyphicon glyphicon-eye-open"></span>',
                        Yii::$app->urlManager->createUrl(['user/view', 'id' => $user->id]),
                        [
                            'title' => 'Voir',
                            'class' => 'btn btn-default'
                        ]);
                },
                'update' => function ($url, $user) {
                    return Html::a('<span class="glyphicon glyphicon-pencil"></span>',
                        Yii::$app->urlManager->createUrl(['user/update', 'id' => $user->id]),
                        [
                            'title' => 'Modifier',
                            'class' => 'btn btn-default'
                        ]);
                },
                'switch' => function($url, $model) use ($userModule, $userCurrent) {
                    if($userModule->getAuthorizationChecker()->isGrantedAsAdministrator($userCurrent)) {
                        return Html::a('<i class="fa fa-fw fa-user-secret"></i>',
                            Yii::$app->urlManager->createUrl(['user/switch-identity', 'id' => $model->id]),
                            [
                                'title' => 'Prendre la main',
                                'class' => 'btn btn-default'
                            ]);
                    }
                }
            ],
        ],
    ],
]); ?>
