<?php

/** 
Copyright Souke (2018)

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs 
à distribuer leur production en circuits courts. 

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant 
donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
*/

use common\helpers\GlobalParam;
use common\helpers\MeanPayment;
use domain\Payment\Payment;
use domain\User\User\UserModule;
use yii\grid\GridView;
use yii\helpers\Html;
use yii\widgets\ActiveForm;

$paymentManager = $this->getPaymentModule();
$producerModule = $this->getProducerModule();
$userModule = $this->getUserModule();

$userModule = UserModule::getInstance();
$username = Html::encode($userModule->getSolver()->getUsername($user));
$this->setTitle($username.' (#'.$user->id.')') ;
$this->addBreadcrumb(['label' => 'Utilisateurs', 'url' => ['index']]) ;
$this->addBreadcrumb(['label' => $username]) ;
$this->addBreadcrumb('Cagnotte') ;

?>

<?= $this->render('_menu_navigation', [
    'action' => 'credit',
    'user' => $user
]); ?>

<div class="user-credit tab-content">
    
    <?php
        $producer = $producerModule->findOneProducerById(GlobalParam::getCurrentProducerId());
        
        if(!$producer->credit)
        {
            echo '<div class="alert alert-warning">Attention, la fonctionnalité <strong>Cagnotte</strong> est désactivée dans vos <a href="'.Yii::$app->urlManager->createurl(['producer/update']).'">paramètres</a>.'
                    . ' Pensez à l\'activer si vous souhaitez qu\'elle soit visible de vos utilisateurs.</div>' ;
        }
    ?>

    <div class="row">
        <div class="col-md-4">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <div class="the-credit">
                        <span class="glyphicon glyphicon-piggy-bank"></span>
                        <?= number_format($userModule->getCredit($user), 2); ?> €
                    </div>
                </div>
            </div>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">
                        Cagnotte obligatoire
                        <?= Html::a($userProducer->credit_active ? 'Désactiver' : 'Activer', ['user/state-credit', 'idUser' => $user->id,'state' => !$userProducer->credit_active], ['class' => 'btn btn-default btn-xs']); ?>
                    </h3>
                </div>
                <div class="panel-body">
                    <p class="info">
                        <span class="glyphicon glyphicon-info-sign"></span>
                        Active ou désactive la cagnotte de l'utilisateur pour les points de vente
                        avec l'option <em>Basée sur l'utilisateur</em>.
                    </p>
                    <?php if($userProducer->credit_active): ?>
                        <div class="alert alert-success">Activé</div>
                    <?php else: ?>
                        <div class="alert alert-danger">Désactivé</div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <div class="col-md-8 ">
            <div class="panel panel-default panel-form-credit-debit">
                <div class="panel-heading">
                    <h3 class="panel-title">
                        Crédit / débit
                    </h3>
                </div>
                <div class="panel-body">
                    <?php $form = ActiveForm::begin(); ?>
                    <div class="row">
                        <div class="col-md-6">
                            <?= $form->field($creditForm, 'type')->dropDownList([
                                Payment::TYPE_CREDIT => 'Crédit',
                                Payment::TYPE_DEBIT => 'Débit',
                            ]) ?>
                            <?= $form->field($creditForm, 'mean_payment')->dropDownList([
                                MeanPayment::MONEY => MeanPayment::getStrBy(MeanPayment::MONEY),
                                MeanPayment::CREDIT_CARD => MeanPayment::getStrBy(MeanPayment::CREDIT_CARD),
                                MeanPayment::CHEQUE => MeanPayment::getStrBy(MeanPayment::CHEQUE),
                                MeanPayment::TRANSFER => MeanPayment::getStrBy(MeanPayment::TRANSFER),
                                MeanPayment::OTHER => MeanPayment::getStrBy(MeanPayment::OTHER),
                            ]) ?>
                            <?= $form->field($creditForm, 'amount')->textInput() ?>
                        </div>
                        <div class="col-md-6">
                            <?= $form->field($creditForm, 'comment')->textarea() ?>
                            <?= $form->field($creditForm, 'date_transaction')->textInput([
                                'class' => 'datepicker form-control'
                            ]) ?>
                            <div class="row">
                                <div class="col-md-8">
                                    <?= $form->field($creditForm, 'send_mail')->checkbox() ?>
                                </div>
                                <div class="col-md-4">
                                    <div class="form-group form-buttons">
                                        <?= Html::submitButton( 'Créditer', ['class' => 'btn btn-primary']) ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php ActiveForm::end(); ?>
                </div>
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-12">
            <div class="panel panel-default panel-form-credit-debit">
                <div class="panel-heading">
                    <h3 class="panel-title">
                        Historique
                    </h3>
                </div>
                <div class="panel-body">
                    <?= GridView::widget([
                        'dataProvider' => $dataProvider,
                        'columns' => [
                            [
                                'attribute' => 'date',
                                'value' => function ($model) use ($paymentManager) {
                                    return $paymentManager->getDate($model, true);
                                }
                            ],
                            [
                                'attribute' => 'id_user_action',
                                'value' => function ($model) use ($paymentManager) {
                                    return $paymentManager->getStrUserAction($model);
                                }
                            ],
                            [
                                'label' => 'Type',
                                'format' => 'raw',
                                'value' => function ($model) use ($paymentManager) {
                                    return $paymentManager->getStrWording($model);
                                }
                            ],
                            [
                                'attribute' => 'mean_payment',
                                'value' => function ($model) use ($paymentManager) {
                                    return $paymentManager->getStrMeanPayment($model);
                                }
                            ],
                            [
                                'label' => '- Débit',
                                'format' => 'raw',
                                'value' => function ($model) use ($paymentManager) {
                                    if ($paymentManager->isTypeDebit($model)) {
                                        return '-&nbsp;' . $paymentManager->getAmount($model, true);
                                    }
                                    return '';
                                }
                            ],
                            [
                                'label' => '+ Crédit',
                                'format' => 'raw',
                                'value' => function ($model) use ($paymentManager) {
                                    if ($paymentManager->isTypeCredit($model)) {
                                        return '+&nbsp;' . $paymentManager->getAmount($model, true);
                                    }
                                    return '';
                                }
                            ],
                            [
                                'label' => 'Commentaire',
                                'format' => 'raw',
                                'value' => function ($model) {
                                    if($model->comment) {
                                        return nl2br($model->comment);
                                    }
                                    return '';
                                }
                            ],
                            [
                                'label' => 'Transaction',
                                'format' => 'raw',
                                'value' => function ($model) {
                                    if($model->date_transaction) {
                                        return date('d/m/Y', strtotime($model->date_transaction));
                                    }
                                    return '';
                                }
                            ],
                        ],
                    ]); ?>
                </div>
            </div>
        </div>
    </div>

    <div class="clr"></div>
</div>
