<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use domain\User\User\UserModule;
use yii\grid\GridView;
use yii\helpers\Html;

$userModule = $this->getUserModule();
$orderModule = $this->getOrderModule();

$userModule = UserModule::getInstance();
$username = Html::encode($userModule->getSolver()->getUsername($user));
$this->setTitle($username.' (#'.$user->id.')') ;
$this->addBreadcrumb(['label' => 'Utilisateurs', 'url' => ['index']]) ;
$this->addBreadcrumb(['label' => $username]) ;
$this->addBreadcrumb('Commandes') ;

?>

<?= $this->render('_menu_navigation', [
    'action' => 'orders',
    'user' => $user
]); ?>

<div class="user-orders tab-content">
    <?= GridView::widget([
        //'filterModel' => $searchModel,
        'dataProvider' => $dataProvider,
        'columns' => [
            [
                'attribute' => 'distribution.date',
                'label' => 'Date',
                'value' => function ($user) {
                    return date('d/m/Y',strtotime($user->distribution->date));
                }
            ],
            [
                'label' => 'Point de vente',
                'format' => 'raw',
                'value' => function ($order) use ($orderModule) {
                    return $orderModule->getPointSaleSummary($order);
                }
            ],
            /*[
                'label' => 'Historique',
                'format' => 'raw',
                'value' => function ($order) use ($orderModule) {
                    return $orderModule->getHistorySummary($order);
                }
            ],*/
            [
                'label' => 'Produits',
                'format' => 'raw',
                'value' => function ($order) use ($orderModule) {
                    return $orderModule->getCartSummary($order);
                }
            ],
            [
                'label' => 'Montant',
                'format' => 'raw',
                'value' => function ($order) use ($orderModule) {
                    $orderModule->initOrder($order);
                    return $orderModule->getAmountSummary($order);
                }
            ],
            [
                'class' => 'yii\grid\ActionColumn',
                'template' => '{update}',
                'headerOptions' => ['class' => 'column-actions'],
                'contentOptions' => ['class' => 'column-actions'],
                'buttons' => [
                    'update' => function ($url, $model) {
                        $url = Yii::$app->urlManager->createUrl(['distribution/index', 'idOrderUpdate' => $model->id]);
                        return Html::a('<span class="glyphicon glyphicon-pencil"></span>', $url, [
                            'title' => 'Modifier', 'class' => 'btn btn-default'
                        ]);
                    },
                ],
            ]
        ],
    ]); ?>
</div>
