<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\components\Tiller;

use linslin\yii2\curl;

class TillerClientV2 implements TillerClientInterface
{
    var $curl;
    var $providerToken;
    var $restaurantToken;
    var $urlApi = 'https://app.tillersystems.com/api/';

    public function __construct(string $providerToken = null, string $restaurantToken = null)
    {
        $this->curl = new curl\Curl();
        $this->providerToken = $providerToken;
        $this->restaurantToken = $restaurantToken;
    }

    public function getUrlAuthorizeCode(string $clientId = null, string $redirectUri = null): string
    {
        return "#";
    }

    public function isAuthenticated(): bool
    {
        return true;
    }

    public function getOrders($date)
    {
        $orders = $this->curl->setGetParams([
            'provider_token' => $this->providerToken,
            'restaurant_token' => $this->restaurantToken,
            'dateFrom' => date('Y-m-d H-i-s', strtotime($date)),
            'dateTo' => date(
                'Y-m-d H-i-s',
                strtotime($date) + 24 * 60 * 60 - 1
            ),
            'status' => 'IN_PROGRESS',
        ])->get($this->urlApi . 'orders');

        return json_decode($orders);
    }

    public function postOrder($params)
    {
        return $this->curl->setPostParams(
            array_merge([
                'provider_token' => $this->providerToken,
                'restaurant_token' => $this->restaurantToken,
            ], $params)
        )
            ->post($this->urlApi . 'orders');
    }
}