<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace domain\Document\Invoice;

use common\helpers\GlobalParam;
use yii\data\ActiveDataProvider;

class InvoiceSearch extends Invoice
{
    var $username;

    public function rules()
    {
        return [
            [[], 'safe'],
            [['comment', 'address', 'status', 'username'], 'string'],
            [['name', 'reference'], 'string', 'max' => 255],
        ];
    }

    public function search($params)
    {
        $invoiceRepository = InvoiceRepository::getInstance();
        $optionsSearch = $invoiceRepository->getDefaultOptionsSearch();

        $query = Invoice::find()
            ->with($optionsSearch['with'])
            ->joinWith($optionsSearch['join_with'])
            ->where(['invoice.id_producer' => GlobalParam::getCurrentProducerId()])
            ->orderBy('invoice.status ASC, invoice.reference DESC')
            ->groupBy('invoice.id');

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'sort' => ['attributes' => ['name', 'reference', 'date']],
            'pagination' => [
                'pageSize' => 20,
            ],
        ]);

        $this->load($params);
        if (!$this->validate()) {
            return $dataProvider;
        }

        $query->andFilterWhere(['like', 'invoice.name', $this->name]);
        $query->andFilterWhere(['like', 'invoice.reference', $this->reference]);
        $query->andFilterWhere(['like', 'invoice.status', $this->status]);

        $query->andFilterWhere([
            'or',
            ['like', 'user_invoice.lastname', $this->username],
            ['like', 'user_invoice.name', $this->username],
            ['like', 'user_invoice.name_legal_person', $this->username],
        ]);

        return $dataProvider;
    }
}
