<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace domain\Feature\Feature;

use common\components\ActiveRecordCommon;
use domain\Feature\FeatureProducer\FeatureProducer;
use yii\db\ActiveQuery;

class Feature extends ActiveRecordCommon
{
    const ALIAS_CONTACT = 'contact';
    const ALIAS_PRODUCT_PRICE_IMPORT = 'product_price_import';
    const ALIAS_ONLINE_PAYMENT = 'online_payment';
    const ALIAS_EXPORT_SHOPPING_CART_LABELS_ADVANCED = 'export_shopping_cart_labels_advanced';
    const ALIAS_SETTINGS = 'settings';

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'feature';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['alias', 'name'], 'required'],
            [['status', 'is_paid_feature', 'only_for_selected_producers'], 'boolean'],
            [['position'], 'integer'],
            [['price'], 'double'],
            [['alias', 'name', 'description'], 'string'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'alias' => 'Alias',
            'name' => 'Nom',
            'description' => 'Description',
            'status' => 'Statut',
            'is_paid_feature' => "Fonctionnalité payante",
            'price' => 'Prix',
            'only_for_selected_producers' => 'Uniquement pour les producteurs sélectionnés',
            'position' => 'Position'
        ];
    }

    public function getFeatureProducers(): ActiveQuery
    {
        return $this->hasMany(FeatureProducer::class, ['id_feature' => 'id']);
    }
}
