<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace domain\Ticket\Ticket;

use common\components\ActiveRecordCommon;
use domain\Producer\Producer\Producer;
use domain\Ticket\TicketMessage\TicketMessage;
use domain\Ticket\TicketUser\TicketUser;
use domain\User\User\User;

class Ticket extends ActiveRecordCommon
{
    const STATUS_OPEN = 'open';
    const STATUS_CLOSED = 'closed';

    public $message;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'ticket';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_producer', 'id_user', 'subject', 'status'], 'required'],
            [['id_producer', 'id_user'], 'integer'],
            [['subject', 'status'], 'string'],
            [['created_at', 'message'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'id_producer' => 'Producteur',
            'id_user' => 'Utilisateur',
            'subject' => 'Sujet',
            'status' => 'Statut',
            'created_at' => 'Ouverture',
            'updated_at' => 'Modification',
        ];
    }

    /*
     * Relations
     */

    public function getProducer()
    {
        return $this->hasOne(Producer::class, ['id' => 'id_producer']);
    }

    public function getUser()
    {
        return $this->hasOne(User::class, ['id' => 'id_user']);
    }

    public function getTicketMessages()
    {
        return $this->hasMany(TicketMessage::class, ['id_ticket' => 'id'])
            ->orderBy(['created_at' => SORT_ASC]);
    }

    public function getTicketUsers()
    {
        return $this->hasMany(TicketUser::class, ['id_ticket' => 'id']);
    }

    public function populateProducer(Producer $producer): void
    {
        $this->populateFieldObject('id_producer', 'producer', $producer);
    }

    public function populateUser(User $user): void
    {
        $this->populateFieldObject('id_user', 'user', $user);
    }
}
