<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use yii\helpers\Html;
use yii\bootstrap\ActiveForm;
use yii\captcha\Captcha;

$this->setTitle("Un outil pour organiser des ventes en circuit court");
$this->setMeta('description', "Souke est un logiciel en ligne permettant aux producteurs locaux d’organiser facilement et en toute autonomie la distribution de leur production en circuit court.") ;

?>
<div class="site-about">
    <div class="row">
        <div class="col-md-8">
            <div class="panel panel-primary panel-padding-large panel-margin-bottom">
                <div class="panel-body">
                    <h2>Présentation</h2>
                    <p>L'objectif de Souke, anciennement Opendistrib, est de fournir aux producteurs locaux une solution technique
                        sur laquelle s'appuyer pour organiser leurs ventes en circuits courts.</p>
                    <p><strong>Le logiciel répond aux besoins quotidiens des producteurs en leur permettant
                        de présenter leur activité, communiquer avec leurs clients, gérer les prises de commandes,
                        comptabiliser les
                            paiements, générer des bons de livraisons/factures et obtenir des statistiques de vente.</strong></p>
                    <p>Cet outil est particulièrement adapté à tous les producteurs souhaitant fonctionner
                        essentiellement sur commande. C'est le choix de cette méthode de travail qui les amène à utiliser
                        cet outil. Majoritairement utilisé par des boulangeries produisant du pain au levain naturel,
                        Souke fonctionne également très bien pour tous types de production locale !</p>
                    <p>La première version du logiciel est née en 2015 à l'occasion de la création de la boulangerie
                        Le Chat des Noisettes à Déservillers, en Franche-Comté. Le site a ensuite été progressivement
                        ouvert à d'autres producteurs un peu partout en France pour arriver à un total de
                        <?= $countProducers ?> producteurs actifs à l'heure actuelle.</p>
                    <p>Le nom <i>Souke</i> fait référence aux <a href="https://fr.wikipedia.org/wiki/Souk">souks</a>,
                        lieux de marché dans les pays arabes.</p>

                    <h2>Qui suis-je ?</h2>
                    <p>Je m'appelle Guillaume Bourgeois et je vis à Besançon en Franche-Comté. J'exerce en
                        tant que développeur web depuis 2009 et suis actuellement en micro-entreprise. </p>
                    <p>Progressivement confronté aux réalités de différents producteurs et distributeurs,
                        également conscient des enjeux sociétaux et environnementaux actuels, je me suis au fil des années
                        intéressé et spécialisé dans le développement de logiciels dédiés à la distribution de produits
                        locaux en circuits courts dont Souke fait partie.</p>
                    <p>Depuis 2015, j'assure donc le développement, la maintenance et le support de Souke.
                        Unique interlocuteur, j'offre aux producteurs une relation directe avec une personne impliquée
                        ayant une vue globale sur tous les aspects du logiciel. Technicien et pédagogue, j'aime être à
                        l'écoute des besoins des producteurs et leur apporter des solutions simples et adaptées.</p>
                </div>
            </div>

            <?php
            $countProducersWithTestimony = count($producersWithTestimonials);
            if($countProducersWithTestimony):
            ?>
                <div class="panel panel-primary panel-padding-large">
                    <div class="panel-body">
                        <h2>Témoignages de producteurs</h2>
                        <div id="carousel-producers-testimonials" class="carousel slide" data-bs-ride="carousel">
                            <!--<ol class="carousel-indicators">
                                <?php for($i = 0; $i <  $countProducersWithTestimony; $i++): ?>
                                    <li data-target="#carousel-producers-testimonials" data-slide-to="<?= $i ?>" <?php if($i == 0): ?>class="active"<?php endif; ?>></li>
                                <?php endfor; ?>
                            </ol>-->
                            <div class="carousel-inner">
                                <?php foreach($producersWithTestimonials as $key => $producerWithTestimony): ?>
                                    <div class="carousel-item<?php if($key == 0): ?> active<?php endif; ?>">
                                        <div class="carousel-caption">
                                            <div class="carousel-caption-inner">
                                                <img src="<?= Yii::$app->urlManagerProducer->getHostInfo() . '/' . Yii::$app->urlManagerProducer->baseUrl; ?>/uploads/<?= $producerWithTestimony->logo; ?>" alt="Logo <?= Html::encode($producerWithTestimony->name) ?>"/>
                                                <div class="producer-testimony">
                                                    <?= nl2br(Html::encode($producerWithTestimony->option_testimony)); ?>
                                                </div>
                                                <div class="producer-details">
                                                    <span class="producer-name"><?= Html::encode($producerWithTestimony->name); ?></span><br />
                                                    <?= Html::encode($producerWithTestimony->city); ?> (<?= Html::encode($producerWithTestimony->postcode); ?>)
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>

                            <button class="left carousel-control-prev" type="button" data-bs-target="#carousel-producers-testimonials" data-bs-slide="prev">
                                <i class="bi bi-chevron-left" aria-hidden="true"></i>
                                <span class="visually-hidden">Previous</span>
                            </button>
                            <button class="right carousel-control-next" type="button" data-bs-target="#carousel-producers-testimonials" data-bs-slide="next">
                                <i class="bi bi-chevron-right" aria-hidden="true"></i>
                                <span class="visually-hidden">Next</span>
                            </button>
                        </div>
                    </div>
                </div>
            <?php endif; ?>

        </div>
        <div class="col-md-4" id="few-numbers">
            <?= $aboutFewNumbers; ?>
        </div>
    </div>
</div>