<?php

/** 
Copyright Souke (2018) 

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs 
à distribuer leur production en circuits courts. 

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant 
donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
*/

use domain\Producer\Producer\ProducerModule;
use yii\bootstrap\ActiveForm;
use yii\helpers\Html;

$producerModule = ProducerModule::getInstance();

$this->setTitle('Connexion nécessaire - '.Html::encode($producer->name)) ;
$this->setMeta('description', 'Connectez-vous pour passer commande auprès du producteur '.Html::encode($producer->name));

?>

<div id="page-producer">

    <div class="btn-group buttons-login-signup">
        <a href="#login" class="btn btn-default">
            <span class="glyphicon glyphicon-log-in"></span>
            Connexion
        </a>
        <a href="#signup" class="btn btn-default">
            <span class="glyphicon glyphicon-user"></span>
            Inscription
        </a>
        <div class="clr"></div>
    </div>

    <div class="alert alert-warning">
        Veuillez vous identifier pour accéder à l'espace du producteur <strong><?= Html::encode($producer->name); ?></strong>.
    </div>

    <div class="row">
        <div class="col-md-6">
            <div class="panel panel-primary panel-padding-large" id="login">
                <div class="panel-heading">
                    <h2 class="panel-title">Connexion</h2>
                </div>
                <div class="panel-body">
                    <?php if(isset($producer) && $producerModule->isDemo($producer)) : ?>
                        <div class="alert alert-warning">
                            <p>Merci d'utiliser les identifiants suivants pour vous connecter à l'espace de démonstration :</p>
                            Identifiant : <strong>demo@souke.fr</strong><br>
                            Mot de passe : <strong>souke123</strong>
                        </div>
                    <?php endif; ?>
                    <?php $form = ActiveForm::begin(['id' => 'login-form','enableClientValidation'=> false]); ?>
                    <?= $form->field($loginForm, 'email') ?>
                    <?= $form->field($loginForm, 'password')->passwordInput() ?>
                    <?= $form->field($loginForm, 'rememberMe')->checkbox() ?>
                    <p>
                        Si vous avez oublié votre mot de passe, vous pouvez le <?= Html::a('réinitialiser', ['site/request-password-reset']) ?>.
                    </p>
                    <div class="form-group form-buttons">
                        <?= Html::submitButton('<i class="bi bi-box-arrow-in-right"></i> Connexion', ['class' => 'btn btn-primary', 'name' => 'login-button']) ?>
                    </div>
                    <?php ActiveForm::end(); ?>
                </div>
            </div>
        </div>

        <div class="col-md-6">
            <div class="panel panel-primary panel-padding-large" id="signup">
                <div class="panel-heading">
                    <h2 class="panel-title">
                        <span class="glyphicon glyphicon-user"></span>
                        Inscription
                    </h2>
                </div>
                <div class="panel-body">
                    <?php $form = ActiveForm::begin(['id' => 'form-signup','enableClientValidation'=> false]); ?>
                    <?= $form->field($signupForm, 'email') ?>
                    <?= $form->field($signupForm, 'password')->passwordInput() ?>
                    <?= $form->field($signupForm, 'lastname') ?>
                    <?= $form->field($signupForm, 'name') ?>
                    <?= $form->field($signupForm, 'phone') ?>
                    <?php if(strlen($producer->code)): ?>
                        <?= $form->field($signupForm, 'code',[
                            'inputTemplate' => '<div class="input-group"><span class="input-group-addon"><span class="glyphicon glyphicon-lock"></span></span>{input}</div>',
                        ])
                            ->label('Code du producteur')
                            ->hint('Renseignez-vous auprès de votre producteur pour qu\'il vous fournisse le code d\'accès') ;  ?>
                    <?php endif; ?>
                    <div class="block-newsletter">
                        <?= $form->field($signupForm, 'newsletter')
                                ->hint(Yii::$app->parameterBag->get('newsletterProducerDescription'))
                                ->checkbox() ?>
                        <?= $form->field($signupForm, 'newsletter_souke')
                                ->hint(Yii::$app->parameterBag->get('newsletterSoukeDescription'))
                                ->checkbox() ?>
                    </div>
                    <?= $form->field($signupForm, 'verifyCode')->widget(\yii\captcha\Captcha::className(), [
                        'template' => '<div class="row"><div class="col-lg-3">{image}</div><div class="col-lg-6">{input}</div></div>',
                    ]) ?>
                    <div class="form-group form-buttons" id="boutons-inscrire">
                        <?= Html::submitButton("<i class=\"bi bi-person-plus\"></i> S'inscrire", ['class' => 'btn btn-primary', 'name' => 'signup-button']) ?>
                    </div>
                    <?php ActiveForm::end(); ?>
                </div>
            </div>
        </div>
    </div>
</div>
