<?php 

/** 
Copyright Souke (2018)

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs 
à distribuer leur production en circuits courts. 

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant 
donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
*/

use common\helpers\GlobalParam;
use domain\User\UserProducer\UserProducerModule;
use yii\helpers\Html;

$userProducerModule = UserProducerModule::getInstance();
$userCurrent = GlobalParam::getCurrentUser();

$this->setTitle('Producteurs') ;
$this->setIcon('grain');
$this->setMeta('description', 'Retrouvez les producteurs présents sur Opendistrib.') ;

?>

<div class="site-producers">
    <div class="row">
        <div class="col-md-6 col-sm-12" id="wrapper-producers-list">
            <div id="producers-list">
                <div id="producer-search">
                    <div class="form-group has-feedback">
                        <input type="text" class="form-control input-lg" placeholder="Recherche par nom, commune ou code postal">
                        <span class="glyphicon glyphicon-search form-control-feedback"></span>
                    </div>
                </div>
                <div class="alert alert-warning alert-no-results">
                    Aucun producteur ne correspond à votre recherche.
                </div>
                <?php foreach($producersArray as $producer): ?>
                <div class="panel panel-default panel-producer">
                    <div class="panel-body">
                        <div class="<?= $producer->logo ? 'col-md-8 col-sm-8' : 'col-md-12'; ?>">
                            <h2><?= Html::encode($producer->name) ?></h2>
                            <p class="producer-type"><?= Html::encode($producer->type) ?></p>
                            <p class="producer-location">
                                <?php if($producer->latitude && $producer->longitude): ?>
                                    <?= Html::a('<span class="glyphicon glyphicon-map-marker"></span> '.Html::encode($producer->postcode.' '.$producer->city),'javascript:void(0);', ['class' => 'btn btn-default view-producer', 'data-id' => $producer->id]);?>
                                <?php else: ?>
                                    <span class="glyphicon glyphicon-map-marker"></span>
                                    <span class="location"><?= Html::encode($producer->postcode.' '.$producer->city); ?></span>
                                <?php endif; ?>

                                <?php if($producer->website): ?>
                                <a href="<?= Html::encode($producer->website); ?>" target="_blank" class="btn btn-default">
                                    <span class="glyphicon glyphicon-globe"></span>
                                    Site web
                                </a>
                                <?php endif; ?>
                            </p>
                        </div>
                        <?php if($producer->logo): ?>
                            <div class="col-md-4 col-sm-4">
                                <div class="logo"<?php if (!is_null($producer->background_color_logo) && strlen($producer->background_color_logo)): ?> style="background-color:<?= Html::encode($producer->background_color_logo); ?>"<?php endif; ?>>
                                    <img class="img-logo"
                                         src="<?= Yii::$app->urlManagerProducer->getHostInfo() . '/' . Yii::$app->urlManagerProducer->baseUrl; ?>/uploads/<?= $producer->logo; ?>"
                                         alt="Logo <?= Html::encode($producer->name) ?>">
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                    <div class="panel-footer">
                        <?= Html::a('Visiter',Yii::$app->urlManagerProducer->createAbsoluteUrl(['site/index', 'slug_producer' => $producer->slug]), ['class'=>'btn btn-primary float-right']) ; ?>

                        <?php if($userCurrent): ?>
                            <?php $this->getLogic()->setProducerContext($producer); ?>
                            <?php if($userProducerModule->isProducerBookmarked($userCurrent)): ?>
                                <?= Html::a('<span class="glyphicon glyphicon-star"></span>', ['bookmark/remove', 'idProducer' => $producer->id], ['class'=>'btn btn-default', 'data-toggle' => 'tooltip', 'data-placement' => 'bottom', 'data-original-title' => 'Supprimer de ma liste de producteurs']) ; ?>
                            <?php else: ?>
                                <?= Html::a('<span class="glyphicon glyphicon-star-empty"></span>', ['bookmark/add', 'idProducer' => $producer->id], ['class'=>'btn btn-default', 'data-toggle' => 'tooltip', 'data-placement' => 'bottom', 'data-original-title' => 'Ajouter à ma liste de producteurs']) ; ?>
                            <?php endif; ?>
                        <?php endif; ?>
                        <div class="clr"></div>
                    </div>
                </div>
                <?php endforeach; ?>
            </div>
        </div>
        <div class="col-md-6 col-sm-12" id="wrapper-producers-map">
            <div id="producers-map"></div>
        </div>
    </div>
    <div class="clr"></div>
<?php
/*
GridView::widget([
    'dataProvider' => $dataProviderProducers,
    'summary' => '',
    'columns' => [
        [
            'attribute' => 'name',
        ],
        [
            'attribute' => 'type',
        ],
        [
            'label' => 'Localisation',
            'value' => function($model) {
                return $model->city. ' ('.$model->postcode.')' ;
            }
        ],
        [
            'label' => 'Lien',
            'format' => 'raw',
            'value' => function($model) {
                $iconLock = (strlen($model->code)) ? ' <span class="glyphicon glyphicon-lock"></span>' : '' ;
                $html = Html::a('Visiter',Yii::$app->urlManagerProducer->createAbsoluteUrl(['site/index', 'slug_producer' => $model->slug]), ['class'=>'btn btn-primary']) ;
                $html .= $iconLock ;
                return $html ;
            }
        ],
    ]
]);
            */
?>

</div>
