<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace producer\controllers;

use yii\filters\AccessControl;

class NewsletterController extends ProducerBaseController
{
    public function behaviors()
    {
        return [];
    }

    public function actionIndex()
    {
        if(!$this->getUserCurrent()) {
            return $this->redirectProducerLoginFrontend('index');
        }

        return $this->render('index', [
            'user' => $this->getUserCurrent(),
            'producer' => $this->getProducerCurrent()
        ]);
    }

    public function actionSubscribe()
    {
        if(!$this->getUserCurrent()) {
            return $this->redirectProducerLoginFrontend('subscribe');
        }

        $userModule = $this->getUserModule();
        $userCurrent = $this->getUserCurrent();
        $userModule->subscribeUserNewsletter($userCurrent);
        //$this->setFlash('success', "<i class=\"bi bi-check2-square\"></i> Votre inscription à l'infolettre a bien été prise en compte.");
        return $this->redirect('index');
    }

    public function actionUnsubscribe()
    {
        if(!$this->getUserCurrent()) {
            return $this->redirectProducerLoginFrontend('unsubscribe');
        }

        $userModule = $this->getUserModule();
        $userCurrent = $this->getUserCurrent();
        $userModule->unsubscribeUserNewsletter($userCurrent);
        //$this->setFlash('success', "<i class=\"bi bi-check2-square\"></i> Votre désinscription a bien été prise en compte, vous ne recevrez plus d'infolettre de la part de ce producteur.");
        return $this->redirect('index');
    }

    public function redirectProducerLoginFrontend(string $actionNewsletter)
    {
        return $this->redirect($this->getUrlManagerFrontend()->createAbsoluteUrl(['site/producer', 'id' => $this->getProducerCurrent()->id, 'return_url' => \Yii::$app->urlManagerProducer->createAbsoluteUrl(['newsletter/'.$actionNewsletter, 'slug_producer' => $this->getProducerCurrent()->slug])]));
    }
}

?>